Index: uspace/lib/ui/src/ui.c
===================================================================
--- uspace/lib/ui/src/ui.c	(revision b71c0fcb07738ec42b4e693c19b1a5c1e2f329a6)
+++ uspace/lib/ui/src/ui.c	(revision d55ab8231eb545c1c99c91124cfdc1401993cbe7)
@@ -38,4 +38,5 @@
 #include <fibril.h>
 #include <stdlib.h>
+#include <task.h>
 #include <ui/ui.h>
 #include "../private/ui.h"
@@ -105,6 +106,6 @@
 /** Execute user interface.
  *
  * This function returns once the application starts the termination
  * process by calling ui_quit(@a ui).
  *
  * @param ui User interface
@@ -112,4 +113,6 @@
 void ui_run(ui_t *ui)
 {
+	task_retval(0);
+
 	while (!ui->quit)
 		fibril_usleep(100000);
@@ -105,6 +106,6 @@
 /** Execute user interface.
  *
- * This function returns once the application starts the termination
- * process by calling ui_quit(@a ui).
+ * Return task exit code of zero and block unitl the application starts
+ * the termination process by calling ui_quit(@a ui).
  *
  * @param ui User interface
